==> cybermut-1.0.tgz: cybermut-1.0/cybermut.c <==
/*
   +----------------------------------------------------------------------+
   | PHP Version 4                                                        |
   +----------------------------------------------------------------------+
   | Copyright (c) 1997-2003 The PHP Group                                |
   +----------------------------------------------------------------------+
   | This source file is subject to version 2.02 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
   | available at through the world-wide-web at                           |
   | http://www.php.net/license/2_02.txt.                                 |
   | If you did not receive a copy of the PHP license and are unable to   |
   | obtain it through the world-wide-web, please send a note to          |
   | license@php.net so we can mail you a copy immediately.               |
   +----------------------------------------------------------------------+
   | Author: CHAILLAN Nicolas <nicos@php.net>                             |
   | Borrowed code from:                                                  |
   |	     Sylvain PAGES <spages@free.fr>                               |
   +----------------------------------------------------------------------+

   $Id: cybermut.c,v 1.13 2003/05/11 19:30:44 nicos Exp $
*/

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "php.h"
#include "php_ini.h"
#include "php_cybermut.h"

#include "cm-mac.h"

PHP_MINFO_FUNCTION(cybermut);
PHP_FUNCTION(cybermut_creerformulairecm);
PHP_FUNCTION(cybermut_testmac);
PHP_FUNCTION(cybermut_creerreponsecm);

/* {{{ cybermut_functions[] */
function_entry spplus_functions[] = {
	PHP_FE(cybermut_creerformulairecm,	NULL)
	PHP_FE(cybermut_testmac,	NULL)
	PHP_FE(cybermut_creerreponsecm,	NULL)
	{NULL, NULL, NULL}	
};
/* }}} */

/* {{{ cybermut_module_entry */
zend_module_entry cybermut_module_entry={
	STANDARD_MODULE_HEADER,
	"cybermut",
	cybermut_functions,
	NULL,
	NULL,
	NULL,
	NULL,
	PHP_MINFO(cybermut),
	"2.0",
	STANDARD_MODULE_PROPERTIES
};
/* }}} */

#ifdef COMPILE_DL_CYBERMUT
ZEND_GET_MODULE(cybermut)
#endif

/* {{{ PHP_MINFO_FUNCTION */
PHP_MINFO_FUNCTION(cybermut)
{
	php_info_print_table_start();
	php_info_print_table_row(2, "CyberMut functions", "enabled");
	php_info_print_table_end();

}
/* }}} */


/* {{{ proto string cybermut_creerformulairecm(string url_cm, string version, string tpe, string montant, string ref_commande, string texte_libre, string url_retour, string url_retour_ok, string url_retour_err, string langue, string code_societe, string texte_bouton)
   Returns a string containing source HTML of the form of request for payment. This result corresponds to the last parameter "formulaire" of the original function which was removed */
PHP_FUNCTION(cybermut_creerformulairecm)
{
	char *url_cm, *version, *tpe, *price, *ref_command, *text_free, *text_button, *url_return, *url_return_ok, *url_return_err, *language, *code_company;
	int url_cm_len, version_len, tpe_len, price_len, ref_command_len, text_free_len, text_button_len, url_return_len, url_return_ok_len, url_return_err_len, language_len, code_company_len;
    char form[10000];

	if (zend_parse_parameters(12, "ssssssssssss", &url_cm, &url_cm_len, &version, &version_len, &tpe, &tpe_len, &price, &price_len, &ref_command, &ref_command_len, &text_free, &text_free_len, &text_button, &text_button_len, &url_return, &url_return_len, &url_return_ok, &url_return_ok_len, &url_return_err, &url_return_err_len, &language, &language_len, &code_company, &code_company_len) == FAILURE) {
		return;
	}

	CreerFormulaireCM(url_cm, version, tpe, price, ref_command, text_free, url_return, url_return_ok, url_return_err, language, code_company, text_button, form);

	RETURN_STRING(form, 1);
}
/* }}} */

/* {{{ proto bool cybermut_testmac(string code_mac, string version, string tpe, string cdate, string montant, string ref_commande, string texte_libre, string code_retour)
   Returns a boolean attesting that the authentification proceeded well. TRUE if the received message is authenticated and FALSE if not */ 
PHP_FUNCTION(cybermut_testmac)
{
	char *code_mac, *version, *tpe, *cdate, *price, *ref_command, *text_free, *code_return;
	int code_mac_len, version_len, tpe_len, cdate_len, price_len, ref_command_len, text_free_len, code_return_len;

	if (zend_parse_parameters(8, "ssssssss", &code_mac, &code_mac_len, &version, &version_len, &tpe, &tpe_len, &cdate, &cdate_len, &price, &price_len, &ref_command, &ref_command_len, &text_free, &text_free_len, &code_return, &code_return_len) == FAILURE) {
		return;
	}

	if(TestMAC(code_mac, version, tpe, cdate, price, ref_command, text_free, code_return)) {
		RETURN_TRUE;
	}
	else {
		RETURN_FALSE;
	}
}
/* }}} */

/* {{{ proto string cybermut_creerreponsecm(string sentence)
   Returns a string containing the message of acknowledgement of delivery (headers and body of the message). This result corresponds to the last parameter "reponse" of the original function which was removed */
PHP_FUNCTION(cybermut_creerreponsecm)
{
	char *sentence;
	int sentence_len;
	char buf[5000];

	if (zend_parse_parameters(1, "s", &sentence, &sentence_len) == FAILURE) {
		return;
	}

	CreerReponseCM(sentence, buf);
	
	RETURN_STRING(buf, 1);
}
/* }}} */

/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * End:
 * vim600: sw=4 ts=4 fdm=marker
 * vim<600: sw=4 ts=4
 */

==> cybermut-1.1.tgz: cybermut-1.1/cybermut.c <==
/*
   +----------------------------------------------------------------------+
   | PHP Version 4                                                        |
   +----------------------------------------------------------------------+
   | Copyright (c) 1997-2003 The PHP Group                                |
   +----------------------------------------------------------------------+
   | This source file is subject to version 2.02 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
   | available at through the world-wide-web at                           |
   | http://www.php.net/license/2_02.txt.                                 |
   | If you did not receive a copy of the PHP license and are unable to   |
   | obtain it through the world-wide-web, please send a note to          |
   | license@php.net so we can mail you a copy immediately.               |
   +----------------------------------------------------------------------+
   | Author: CHAILLAN Nicolas <nicos@php.net>                             |
   | Borrowed code from:                                                  |
   |	     Sylvain PAGES <spages@free.fr>                               |
   +----------------------------------------------------------------------+

   $Id: cybermut.c,v 1.14 2003/06/03 10:57:54 nicos Exp $
*/

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "php.h"
#include "php_ini.h"
#include "php_cybermut.h"

#include "cm-mac.h"

PHP_MINFO_FUNCTION(cybermut);
PHP_FUNCTION(cybermut_creerformulairecm);
PHP_FUNCTION(cybermut_testmac);
PHP_FUNCTION(cybermut_creerreponsecm);

/* {{{ cybermut_functions[] */
function_entry cybermut_functions[] = {
	PHP_FE(cybermut_creerformulairecm,	NULL)
	PHP_FE(cybermut_testmac,	NULL)
	PHP_FE(cybermut_creerreponsecm,	NULL)
	{NULL, NULL, NULL}	
};
/* }}} */

/* {{{ cybermut_module_entry */
zend_module_entry cybermut_module_entry={
	STANDARD_MODULE_HEADER,
	"cybermut",
	cybermut_functions,
	NULL,
	NULL,
	NULL,
	NULL,
	PHP_MINFO(cybermut),
	"2.0",
	STANDARD_MODULE_PROPERTIES
};
/* }}} */

#ifdef COMPILE_DL_CYBERMUT
ZEND_GET_MODULE(cybermut)
#endif

/* {{{ PHP_MINFO_FUNCTION */
PHP_MINFO_FUNCTION(cybermut)
{
	php_info_print_table_start();
	php_info_print_table_row(2, "CyberMut functions", "enabled");
	php_info_print_table_end();

}
/* }}} */


/* {{{ proto string cybermut_creerformulairecm(string url_cm, string version, string tpe, string montant, string ref_commande, string texte_libre, string url_retour, string url_retour_ok, string url_retour_err, string langue, string code_societe, string texte_bouton)
   Returns a string containing source HTML of the form of request for payment. This result corresponds to the last parameter "formulaire" of the original function which was removed */
PHP_FUNCTION(cybermut_creerformulairecm)
{
	char *url_cm, *version, *tpe, *price, *ref_command, *text_free, *text_button, *url_return, *url_return_ok, *url_return_err, *language, *code_company;
	int url_cm_len, version_len, tpe_len, price_len, ref_command_len, text_free_len, text_button_len, url_return_len, url_return_ok_len, url_return_err_len, language_len, code_company_len;
    char form[10000];

	if (zend_parse_parameters(12, "ssssssssssss", &url_cm, &url_cm_len, &version, &version_len, &tpe, &tpe_len, &price, &price_len, &ref_command, &ref_command_len, &text_free, &text_free_len, &text_button, &text_button_len, &url_return, &url_return_len, &url_return_ok, &url_return_ok_len, &url_return_err, &url_return_err_len, &language, &language_len, &code_company, &code_company_len) == FAILURE) {
		return;
	}

	CreerFormulaireCM(url_cm, version, tpe, price, ref_command, text_free, url_return, url_return_ok, url_return_err, language, code_company, text_button, form);

	RETURN_STRING(form, 1);
}
/* }}} */

/* {{{ proto bool cybermut_testmac(string code_mac, string version, string tpe, string cdate, string montant, string ref_commande, string texte_libre, string code_retour)
   Returns a boolean attesting that the authentification proceeded well. TRUE if the received message is authenticated and FALSE if not */ 
PHP_FUNCTION(cybermut_testmac)
{
	char *code_mac, *version, *tpe, *cdate, *price, *ref_command, *text_free, *code_return;
	int code_mac_len, version_len, tpe_len, cdate_len, price_len, ref_command_len, text_free_len, code_return_len;

	if (zend_parse_parameters(8, "ssssssss", &code_mac, &code_mac_len, &version, &version_len, &tpe, &tpe_len, &cdate, &cdate_len, &price, &price_len, &ref_command, &ref_command_len, &text_free, &text_free_len, &code_return, &code_return_len) == FAILURE) {
		return;
	}

	if(TestMAC(code_mac, version, tpe, cdate, price, ref_command, text_free, code_return)) {
		RETURN_TRUE;
	}
	else {
		RETURN_FALSE;
	}
}
/* }}} */

/* {{{ proto string cybermut_creerreponsecm(string sentence)
   Returns a string containing the message of acknowledgement of delivery (headers and body of the message). This result corresponds to the last parameter "reponse" of the original function which was removed */
PHP_FUNCTION(cybermut_creerreponsecm)
{
	char *sentence;
	int sentence_len;
	char buf[5000];

	if (zend_parse_parameters(1, "s", &sentence, &sentence_len) == FAILURE) {
		return;
	}

	CreerReponseCM(sentence, buf);
	
	RETURN_STRING(buf, 1);
}
/* }}} */

/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * End:
 * vim600: sw=4 ts=4 fdm=marker
 * vim<600: sw=4 ts=4
 */
